#!perl

use strict;
use HesiodLDAP qw(resolve);

# make a type tester
my %IS_TYPE = map { $_ => 1 } @HesiodLDAP::types;

# clean and collect args
my @params = map { lc($_) } @ARGV;
my $VERBOSE = 0;
if ( $params[0] =~ /\A - -? v/xms ) {
    shift @params;
    $VERBOSE = 1;
}

# need usage?
if ( !@params ) {
    die <<"USAGE";
Usage:  hes.pl [-v] [Identity ...] [Hesiod_Type] [...]
USAGE
}

while (@params) {

    # loop through the params looking for ids followed by a type
    my @ids  = ();
    my $type = undef;

WHILENEXT:
    while ( my $next = shift @params ) {
        if ( $IS_TYPE{$next} ) {
            $type = $next;
            last WHILENEXT;
        }
        push @ids, $next;
    }

    # once a type is found, apply it to all ids so far
    # if no type was found, resolve all available entries for each id
    foreach my $id (@ids) {
        my $result = resolve( $id, $type );
        if ( $result ) {
            print $result, ( defined $type ? "\n" : '' );
        }
        elsif ($VERBOSE && defined $HesiodLDAP::last_error) {
            print STDERR "resolve $id: $HesiodLDAP::last_error\n";
        }
    }
}

__END__

=head1 NAME

hes.pl - Perl/LDAP replacement for Hesiod database queries


=head1 VERSION

This documentation refers to hes.pl version 1.0.0.


=head1 USAGE

    hes.pl [-v] [Identity ...] [Hesiod_Type] [...]


=head1 OPTIONS

=head2 -v  (Verbose)

Enable verbose reporting of errors.

=head2 Identity

One or more identities to lookup. The following types of identities 
may be used:

=over

username,
uid_number,
groupname,
gid_number,
locker_name,
hostname

=back

=head2 Hesiod_Type

The following types of identifiers may be used in the Hesiod_Type 
argument. These values specify the kinds of queries to make to the
database. 

=over

passwd,
filsys,
pobox,
gid,
uid,
grplist,
group,
cluster

=back

=head1 DESCRIPTION

hes.pl can be invoked with any number of Identities followed by a 
Hesiod_Type specifying which kind of information to retrieve from the 
database. If no Hesiod_Type is given, all known types of information 
are asked for.


=head1 DIAGNOSTICS

By default, this application does not return error messages or codes.
When a lookup fails, it simply returns no results.

When the C<< -v >> option is specified, the L<<HesiodLDAP>> perl module
errors will be reported to standard error. See that man page for details
on the messages that could be returned.


=head1 DEPENDENCIES

L<HesiodLDAP> perl module - packaged with this script

L<Net::LDAP> perl module - for LDAP access


=head1 INCOMPATIBILITIES

See the L<HesiodLDAP> man page for details of incompatibilities between
the old Hesiod database and the LDAP replacements.


=head1 BUGS AND LIMITATIONS

There are no known bugs in this application.

Please report problems to the author.


=head1 AUTHOR

Charles J. Brabec  C<< <brabec@ncsu.edu> >>


=head1 LICENCE AND COPYRIGHT

Copyright (c) 2007, NC State University.  All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.


=head1 DISCLAIMER OF WARRANTY

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

